# Automatise: Multiple Aspect Trajectory Data Mining Tool Library
---

Welcome to Automatise Framework for Multiple Aspect Trajectory Analysis.

The present application offers a tool, called AutoMATise, to support the user in the classification task of multiple aspect trajectories, specifically for extracting and visualizing the movelets, the parts of the trajectory that better discriminate a class. The AutoMATise integrates into a unique platform the fragmented approaches available for multiple aspects trajectories and in general for multidimensional sequence classification into a unique web-based and python library system. Offers both movelets visualization and a complete configuration of classification experimental settings.

- [Analysis](/analysis): Multiple Aspect Trajectory Analysis Tool;
- [Methods](/methods): Methods for trajectory classification and movelet extraction;
- [Datasets](/datasets): Datasets descriptions and files;
- [Experiments](/experiments): Experiments on trajectory datasets and method rankings;
- [Publications](/publications): Multiple Aspect Trajectory Analysis related publications.

To use Automatise as a python library, find examples in this sample Jupyter Notebbok: [Automatise_Sample_Code.ipynb](./assets/examples/Automatise_Sample_Code.ipynb)

### Reference:

Portela, Tarlis Tortelli; Bogorny, Vania; Bernasconi, Anna; Renso, Chiara. **AutoMATitse: Multiple Aspect Trajectory Data Mining Tool Library.** 2022. 23rd IEEE International Conference on Mobile Data Management (MDM), 2022, pp. xxx-xxx, doi: xxx.